/*****************************************************************************
 * Copyright (c) 2015 CEA LIST.
 *
 *    
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *  Benoit Maggi (CEA LIST) benoit.maggi@cea.fr - Initial API and implementation
 *  
 *****************************************************************************/
package org.eclipse.papyrus.sysml14.diagram.common.edit.parts;

import org.eclipse.draw2d.IFigure;
import org.eclipse.draw2d.PositionConstants;
import org.eclipse.gmf.runtime.diagram.ui.figures.IBorderItemLocator;
import org.eclipse.gmf.runtime.notation.View;
import org.eclipse.papyrus.sysml14.deprecatedelements.FlowPort;
import org.eclipse.papyrus.sysml14.diagram.common.Activator;
import org.eclipse.papyrus.sysml14.diagram.common.figure.FlowPortFigure;
import org.eclipse.papyrus.sysml14.diagram.common.locator.FixedPortPositionLocator;
import org.eclipse.papyrus.uml.diagram.common.figure.node.AffixedNamedElementFigure;
import org.eclipse.swt.graphics.Image;
import org.eclipse.uml2.uml.Element;
import org.eclipse.uml2.uml.util.UMLUtil;

/**
 * This class implements an edit part for FlowPort represented as border items.
 */
public class FlowPortEditPart extends org.eclipse.papyrus.uml.diagram.common.editparts.AroundBorderItemEditPart {

	private FlowPortFigure aprimaryShape;

	/**
	 * Constructor.
	 *
	 * @param view
	 */
	public FlowPortEditPart(View view) {
		super(view);
	}

	@Override
	public AffixedNamedElementFigure getPrimaryShape() {
		return (FlowPortFigure) aprimaryShape;
	}
	
	@Override
	protected IFigure createNodeShape() {
		aprimaryShape = new FlowPortFigure();
		return aprimaryShape;
	}

	
	@Override
	public IBorderItemLocator getNewBorderItemLocator(IFigure mainFigure) {
		org.eclipse.papyrus.uml.diagram.common.locator.PortPositionLocator portPositionLocator= new FixedPortPositionLocator(mainFigure, PositionConstants.NONE);
		portPositionLocator.setBorderItemOffset(0);
		return portPositionLocator;
	}
	
	/**
	 * @see org.eclipse.papyrus.uml.diagram.common.editparts.RoundedBorderNamedElementEditPart#refreshVisuals()
	 *
	 */
	@Override
	protected void refreshVisuals() {
		super.refreshVisuals();
		Element element = (Element) resolveSemanticElement();
		FlowPort flowPort = UMLUtil.getStereotypeApplication(element, FlowPort.class);
		
		Image image = new Activator().getFlowPortImage(flowPort, getBorderItemLocator().getCurrentSideOfParent());
		aprimaryShape.setImage(image);
	}
	
}
