/*****************************************************************************
 * Copyright (c) 2015 CEA LIST.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *  Francois Le Fevre (CEA LIST) francois.le-fevre@cea.fr - Initial API and implementation
 *****************************************************************************/
package org.eclipse.papyrus.sysml14.util;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.uml2.uml.Element;
import org.eclipse.uml2.uml.Namespace;
import org.eclipse.uml2.uml.Stereotype;

/**
 * Utility class to get informations on DeprecatedElement resources
 *
 */
public final class DeprecatedElementUtil {
	//TODO update the norm extraction to be able to catch the deprecated elements.
	private DeprecatedElementUtil(){

	}

	/**
	 * @param eObject
	 * @return It returns true if the EObject is a deprecated Stereotype or if the Uml element is stereotyped by a deprecated stereotype
	 */
	//TODO an optimization could be possible but with introducing static attributes matching to FlowSpecification and FlowPort
	public static boolean isDeprecatedElement(EObject eObject) {
		if(eObject instanceof Element){
			for(Stereotype s : ((Element)eObject).getAppliedStereotypes()){
				for(Namespace n : s.allNamespaces()){
					if("SysML::DeprecatedElements".equals(n.getQualifiedName())){ //$NON-NLS-1$
						return true;
					}
				}
			}
		}
		if(eObject!=null){
			return eObject.getClass().toString().contains("org.eclipse.papyrus.sysml14.deprecatedelements"); //$NON-NLS-1$
		}
		else{
			return false;
		}
	}


}
