/*****************************************************************************
 * Copyright (c) 2015 CEA LIST.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *  Benoit Maggi (CEA LIST) benoit.maggi@cea.fr - Initial API and implementation
 *****************************************************************************/
package org.eclipse.papyrus.sysml14.util;

import org.eclipse.emf.common.util.URI;
import org.eclipse.emf.ecore.resource.Resource;
import org.eclipse.emf.ecore.resource.ResourceSet;
import org.eclipse.emf.ecore.util.EcoreUtil;
import org.eclipse.uml2.uml.Model;
import org.eclipse.uml2.uml.Profile;
import org.eclipse.uml2.uml.UMLFactory;
import org.eclipse.uml2.uml.UMLPackage;
import org.eclipse.uml2.uml.resource.UMLResource;

/**
 * Utility class to get informations on SysML resources
 *
 */
public final class SysMLResource {

	private SysMLResource(){
		
	}
	
	public static final String PROFILE_PATH = "platform:/plugin/org.eclipse.papyrus.sysml14/resources/profile/SysML.profile.uml"; //$NON-NLS-1$

	public static final String PROFILE_URI = "http://www.eclipse.org/papyrus/sysml/1.4/SysML"; //$NON-NLS-1$

	public static final String LIBRARY_PATH = "platform:/plugin/org.eclipse.papyrus.sysml14/resources/library/SysML-Standard-Library.uml"; //$NON-NLS-1$

	private static final String UNNAMED = "unnamed"; //$NON-NLS-1$
	
	/**
	 * Creates a model with SysML profile applied
	 *
	 * @param resourceSet
	 *        the resource set in which to create the model
	 * @return the created model
	 */
	public static Model createSysMLModel(ResourceSet resourceSet) {//, String modelName
		return createSysMLModel(resourceSet, UNNAMED+"."+UMLResource.FILE_EXTENSION, UNNAMED); //$NON-NLS-1$
	}

	/**
	 * Creates a model with SysML profile applied
	 *  
	 * @param resourceSet the resource set in which to create the model
	 * @param resourceName name of the resource
	 * @param modelName name of the model
	 * @return the created model
	 */
	public static Model createSysMLModel(ResourceSet resourceSet, String resourceName, String modelName) {
		Model model = UMLFactory.eINSTANCE.createModel();
		model.setName(modelName);
		Resource resource = resourceSet.createResource(URI.createURI(resourceName));
		resource.getContents().add(model);
		// Apply UML Standard profile
		// Retrieve standard profile
		Resource standardProfileResource = resourceSet.getResource(URI.createURI(UMLResource.STANDARD_PROFILE_URI), true);
		Profile umlStdProfile = (Profile) EcoreUtil.getObjectByType(standardProfileResource.getContents(), UMLPackage.Literals.PACKAGE);
		// Apply to the model
		model.applyProfile(umlStdProfile);
		// Retrieve SysML profile and apply with subprofile
		Resource sysmlProfileResource = resourceSet.getResource(URI.createURI(SysMLResource.PROFILE_PATH), true);
		Profile sysmlProfile = (Profile) EcoreUtil.getObjectByType(sysmlProfileResource.getContents(), UMLPackage.Literals.PACKAGE);
		model.applyProfile(sysmlProfile);
		return model;
	}
	
}
